@@ -30,7 +30,7 @@ use DynaLoader ();
 use Carp;
 
 use vars   qw( $VERSION @ISA );
-$VERSION = "0.71";
+$VERSION = "0.72";
 @ISA     = qw( DynaLoader );
 bootstrap Text::CSV_XS $VERSION;
 
@@ -60,6 +60,7 @@ my %def_attr = (
     eol			=> '',
     always_quote	=> 0,
     quote_space		=> 1,
+    quote_null		=> 1,
     binary		=> 0,
     keep_meta_info	=> 0,
     allow_loose_quotes	=> 0,
@@ -150,6 +151,7 @@ my %_cache_id = ( # Only expose what is accessed from within PM
     empty_is_undef	=> 23,
     auto_diag		=> 24,
     quote_space		=> 25,
+    quote_null		=> 31,
     _is_bound		=> 26,	# 26 .. 29
     );
 
@@ -237,6 +239,13 @@ sub quote_space
     $self->{quote_space};
     } # quote_space
 
+sub quote_null
+{
+    my $self = shift;
+    @_ and $self->_set_attr_X ("quote_null", shift);
+    $self->{quote_null};
+    } # quote_null
+
 sub binary
 {
     my $self = shift;
@@ -354,7 +363,7 @@ sub error_diag
     my $context = wantarray;
     unless (defined $context) {	# Void context, auto-diag
 	if ($diag[0] && $diag[0] != 2012) {
-	    my $msg = "# CSV_XS ERROR: $diag[0] - $diag[1]\n";
+	    my $msg = "# CSV_XS ERROR: $diag[0] - $diag[1] \@ pos $diag[2]\n";
 	    if ($self && ref $self) {	# auto_diag
 
 		my $lvl = $self->{auto_diag};
@@ -933,7 +942,14 @@ Text::CSV_XS. :-)
 By default, a space in a field would trigger quotation. As no rule
 exists this to be forced in CSV, nor any for the opposite, the default
 is true for safety. You can exclude the space from this trigger by
-setting this option to 0.
+setting this attribute to 0.
+
+=item quote_null
+
+By default, a NULL byte in a field would be escaped. This attribute
+enables you to treat the NULL byte as a simple binary character in
+binary mode (the C<{ binary => 1 }> is set). The default is true.
+You can prevent NULL escapes by setting this attribute to 0.
 
 =item keep_meta_info
 
@@ -982,7 +998,7 @@ anymore, and getline () chomps line endings on reading.
 Set to true will cause C<error_diag ()> to be automatically be called
 in void context upon errors.
 
-In case of error C<2012 - EOF>), this call will be void.
+In case of error C<2012 - EOF>, this call will be void.
 
 If set to a value greater than 1, it will die on errors instead of
 warn.
@@ -1006,6 +1022,7 @@ is equivalent to
      eol                 => $\,
      always_quote        => 0,
      quote_space         => 1,
+     quote_null	         => 1,
      binary              => 0,
      keep_meta_info      => 0,
      allow_loose_quotes  => 0,
